@@ -10,8 +10,6 @@ G_BEGIN_DECLS
 /* enumerations from "./bacon-video-widget.h" */
 GType bvw_error_get_type (void) G_GNUC_CONST;
 #define BVW_TYPE_ERROR (bvw_error_get_type())
-GType bvw_connection_speed_get_type (void) G_GNUC_CONST;
-#define BVW_TYPE_CONNECTION_SPEED (bvw_connection_speed_get_type())
 GType bvw_metadata_type_get_type (void) G_GNUC_CONST;
 #define BVW_TYPE_METADATA_TYPE (bvw_metadata_type_get_type())
 GType bvw_visualization_quality_get_type (void) G_GNUC_CONST;
@@ -22,6 +20,8 @@ GType bvw_aspect_ratio_get_type (void) G_GNUC_CONST;
 #define BVW_TYPE_ASPECT_RATIO (bvw_aspect_ratio_get_type())
 GType bvw_zoom_mode_get_type (void) G_GNUC_CONST;
 #define BVW_TYPE_ZOOM_MODE (bvw_zoom_mode_get_type())
+GType bvw_rotation_get_type (void) G_GNUC_CONST;
+#define BVW_TYPE_ROTATION (bvw_rotation_get_type())
 GType bvw_dvd_event_get_type (void) G_GNUC_CONST;
 #define BVW_TYPE_DVD_EVENT (bvw_dvd_event_get_type())
 GType bvw_audio_output_type_get_type (void) G_GNUC_CONST;
