@@ -47,6 +47,7 @@
 #include <totem-time-helpers.h>
 
 #include "totem-search-entry.h"
+#include <libgd/gd.h>
 
 #define TOTEM_TYPE_GRILO_PLUGIN                                         \
 	(totem_grilo_plugin_get_type ())
@@ -70,7 +71,7 @@
 	"</ui>"
 
 #define BROWSE_FLAGS          (GRL_RESOLVE_FAST_ONLY | GRL_RESOLVE_IDLE_RELAY)
-#define RESOLVE_FLAGS 	      (GRL_RESOLVE_FULL | GRL_RESOLVE_IDLE_RELAY)
+#define RESOLVE_FLAGS         (GRL_RESOLVE_FULL | GRL_RESOLVE_IDLE_RELAY)
 #define PAGE_SIZE             50
 #define THUMB_SEARCH_SIZE     256
 #define THUMB_BROWSE_SIZE     32
@@ -86,9 +87,7 @@ const gchar *BLACKLIST_SOURCES[] = { "grl-filesystem",
 
 typedef enum {
 	ICON_BOX = 0,
-	ICON_AUDIO,
-	ICON_VIDEO,
-	ICON_DEFAULT
+	ICON_VIDEO
 } IconType;
 
 typedef struct {
@@ -147,12 +146,9 @@ enum {
 };
 
 enum {
-	MODEL_RESULTS_SOURCE = 0,
+	MODEL_RESULTS_SOURCE = GD_MAIN_COLUMN_LAST,
 	MODEL_RESULTS_CONTENT,
-	MODEL_RESULTS_THUMBNAIL,
 	MODEL_RESULTS_IS_PRETHUMBNAIL,
-	MODEL_RESULTS_DESCRIPTION,
-	MODEL_RESULTS_DURATION,
 	MODEL_RESULTS_PAGE,
 	MODEL_RESULTS_REMAINING,
 };
@@ -163,23 +159,18 @@ static void play (TotemGriloPlugin *self,
                   gboolean resolve_url);
 
 static gchar *
-get_description (GrlMedia *media)
+get_secondary_text (GrlMedia *media)
 {
-	const gchar *author;
+	const char *artist;
+	int duration;
 
-	author = grl_data_get_string (GRL_DATA (media), GRL_METADATA_KEY_AUTHOR);
-	if (author == NULL) {
-		author = grl_data_get_string (GRL_DATA (media), GRL_METADATA_KEY_ARTIST);
-	}
-
-	if (author != NULL) {
-		return g_markup_printf_escaped ("<b>%s</b>\n%s",
-		                                grl_media_get_title (media),
-		                                author);
-	} else {
-		return g_markup_printf_escaped ("<b>%s</b>",
-		                                grl_media_get_title (media));
-	}
+	artist = grl_data_get_string (GRL_DATA (media), GRL_METADATA_KEY_ARTIST);
+	if (artist != NULL)
+		return g_strdup (artist);
+	duration = grl_media_get_duration (media);
+	if (duration > 0)
+		return totem_time_to_string (duration * 1000);
+	return NULL;
 }
 
 static GList *
@@ -208,6 +199,7 @@ search_keys (void)
 	if (_search_keys == NULL) {
 		_search_keys = grl_metadata_key_list_new (GRL_METADATA_KEY_ARTIST,
 		                                          GRL_METADATA_KEY_AUTHOR,
+		                                          GRL_METADATA_KEY_DURATION,
 		                                          GRL_METADATA_KEY_THUMBNAIL,
 		                                          GRL_METADATA_KEY_URL,
 		                                          GRL_METADATA_KEY_TITLE,
@@ -224,9 +216,7 @@ load_icon (TotemGriloPlugin *self, IconType icon_type, gint thumb_size)
 	GtkIconTheme *theme;
 
 	const gchar *icon_name[] = { GTK_STOCK_DIRECTORY,
-	                             "audio-x-generic",
-	                             "video-x-generic",
-	                             GTK_STOCK_FILE };
+	                             "video-x-generic" };
 
 	static GdkPixbuf *pixbuf[G_N_ELEMENTS(icon_name)] = { NULL };
 
@@ -238,11 +228,10 @@ load_icon (TotemGriloPlugin *self, IconType icon_type, gint thumb_size)
 		                                              thumb_size, 0, NULL);
 	}
 
-	if (pixbuf[icon_type] != NULL) {
+	if (pixbuf[icon_type] != NULL)
 		return g_object_ref (pixbuf[icon_type]);
-	} else {
+	else
 		return NULL;
-	}
 }
 
 static GdkPixbuf *
@@ -250,13 +239,10 @@ get_icon (TotemGriloPlugin *self, GrlMedia *media, gint thumb_size)
 {
 	if (GRL_IS_MEDIA_BOX (media)) {
 		return load_icon (self, ICON_BOX, thumb_size);
-	} else if (GRL_IS_MEDIA_AUDIO (media)) {
-		return load_icon (self, ICON_AUDIO, thumb_size);
 	} else if (GRL_IS_MEDIA_VIDEO (media)) {
 		return load_icon (self, ICON_VIDEO, thumb_size);
-	} else {
-		return load_icon (self, ICON_DEFAULT, thumb_size);
 	}
+	return NULL;
 }
 
 static void
@@ -285,7 +271,7 @@ get_stream_thumbnail_cb (GObject *source_object,
 	if (thumbnail) {
 		gtk_list_store_set (GTK_LIST_STORE (thumb_data->totem_grilo->priv->search_results_model),
 		                    &iter,
-		                    MODEL_RESULTS_THUMBNAIL, thumbnail,
+		                    GD_MAIN_COLUMN_ICON, thumbnail,
 		                    -1);
 		/* Cache it */
 		g_hash_table_insert (thumb_data->totem_grilo->priv->cache_thumbnails,
@@ -332,7 +318,7 @@ set_thumbnail_async (TotemGriloPlugin *self, GrlMedia *media, GtkTreePath *path,
 			gtk_tree_model_get_iter (self->priv->search_results_model, &iter, path);
 			gtk_list_store_set (GTK_LIST_STORE (self->priv->search_results_model),
 			                    &iter,
-			                    MODEL_RESULTS_THUMBNAIL, thumbnail,
+			                    GD_MAIN_COLUMN_ICON, thumbnail,
 			                    -1);
 		}
 	} else {
@@ -359,9 +345,9 @@ update_search_thumbnails_idle (TotemGriloPlugin *self)
 		for (;
 		     gtk_tree_path_compare (start_path, end_path) <= 0;
 		     gtk_tree_path_next (start_path)) {
-			if (gtk_tree_model_get_iter (self->priv->search_results_model, &iter, start_path) == FALSE) {
+
+			if (gtk_tree_model_get_iter (self->priv->search_results_model, &iter, start_path) == FALSE)
 				break;
-			}
 
 			gtk_tree_model_get (self->priv->search_results_model,
 			                    &iter,
@@ -405,7 +391,7 @@ show_sources (TotemGriloPlugin *self)
 	                                                  GRL_OP_BROWSE,
 	                                                  FALSE);
 
-	for (source = sources; source ; source = g_list_next (source)) {
+	for (source = sources; source ; source = source->next) {
 		icon = load_icon (self, ICON_BOX, THUMB_BROWSE_SIZE);
 		name = grl_source_get_name (source->data);
 		gtk_tree_store_append (GTK_TREE_STORE (self->priv->browser_model), &iter, NULL);
@@ -413,13 +399,12 @@ show_sources (TotemGriloPlugin *self)
 		                    &iter,
 		                    MODEL_RESULTS_SOURCE, source->data,
 		                    MODEL_RESULTS_CONTENT, NULL,
-		                    MODEL_RESULTS_DESCRIPTION, name,
-		                    MODEL_RESULTS_THUMBNAIL, icon,
+		                    GD_MAIN_COLUMN_PRIMARY_TEXT, name,
+		                    GD_MAIN_COLUMN_ICON, icon,
 		                    MODEL_RESULTS_IS_PRETHUMBNAIL, FALSE,
 		                    -1);
-		if (icon != NULL) {
-			g_object_unref (icon);
-		}
+
+		g_clear_object (&icon);
 	}
 	g_list_free (sources);
 }
@@ -432,9 +417,6 @@ browse_cb (GrlSource *source,
            gpointer user_data,
            const GError *error)
 {
-	gchar *description;
-	gchar *pretty_duration;
-	gint duration;
 	GtkTreeIter iter;
 	GdkPixbuf *thumbnail;
 	BrowseUserData *bud;
@@ -456,6 +438,8 @@ browse_cb (GrlSource *source,
 	}
 
 	if (media != NULL) {
+		char *secondary;
+
 		gtk_tree_model_get_iter (self->priv->browser_model, &parent, gtk_tree_row_reference_get_path (bud->ref_parent));
 		gtk_tree_model_get (self->priv->browser_model, &parent,
 		                    MODEL_RESULTS_REMAINING, &remaining_expected,
@@ -465,42 +449,37 @@ browse_cb (GrlSource *source,
 		                    MODEL_RESULTS_REMAINING, &remaining_expected,
 		                    -1);
 		/* Filter images */
-		if (GRL_IS_MEDIA_IMAGE (media) == FALSE) {
-			thumbnail = get_icon (self, media, THUMB_BROWSE_SIZE);
-			description = get_description (media);
-			duration = grl_media_get_duration (media);
-			if (duration > 0) {
-				pretty_duration = totem_time_to_string (duration * 1000);
-			} else {
-				pretty_duration = NULL;
-			}
-
-			gtk_tree_store_append (GTK_TREE_STORE (self->priv->browser_model), &iter, &parent);
-			gtk_tree_store_set (GTK_TREE_STORE (self->priv->browser_model),
-			                    &iter,
-			                    MODEL_RESULTS_SOURCE, source,
-			                    MODEL_RESULTS_CONTENT, media,
-			                    MODEL_RESULTS_THUMBNAIL, thumbnail,
-			                    MODEL_RESULTS_IS_PRETHUMBNAIL, TRUE,
-			                    MODEL_RESULTS_DESCRIPTION, description,
-			                    MODEL_RESULTS_DURATION, pretty_duration,
-			                    -1);
-
-			if (thumbnail != NULL) {
-				g_object_unref (thumbnail);
-			}
-			g_free (description);
-			g_free (pretty_duration);
-
-			path = gtk_tree_model_get_path (self->priv->browser_model, &parent);
-			gtk_tree_view_expand_row (GTK_TREE_VIEW (self->priv->browser), path, FALSE);
-			gtk_tree_view_columns_autosize (GTK_TREE_VIEW (self->priv->browser));
-			gtk_tree_path_free (path);
+		if (GRL_IS_MEDIA_IMAGE (media) ||
+		    GRL_IS_MEDIA_AUDIO (media)) {
+			g_object_unref (media);
+			goto out;
 		}
 
+		thumbnail = get_icon (self, media, THUMB_BROWSE_SIZE);
+		secondary = get_secondary_text (media);
+
+		gtk_tree_store_append (GTK_TREE_STORE (self->priv->browser_model), &iter, &parent);
+		gtk_tree_store_set (GTK_TREE_STORE (self->priv->browser_model),
+				    &iter,
+				    MODEL_RESULTS_SOURCE, source,
+				    MODEL_RESULTS_CONTENT, media,
+				    GD_MAIN_COLUMN_ICON, thumbnail,
+				    MODEL_RESULTS_IS_PRETHUMBNAIL, TRUE,
+				    GD_MAIN_COLUMN_PRIMARY_TEXT, grl_media_get_title (media),
+				    GD_MAIN_COLUMN_SECONDARY_TEXT, secondary,
+				    -1);
+
+		g_clear_object (&thumbnail);
+		g_free (secondary);
+
+		path = gtk_tree_model_get_path (self->priv->browser_model, &parent);
+		gtk_tree_view_expand_row (GTK_TREE_VIEW (self->priv->browser), path, FALSE);
+		gtk_tree_view_columns_autosize (GTK_TREE_VIEW (self->priv->browser));
+		gtk_tree_path_free (path);
 		g_object_unref (media);
 	}
 
+out:
 	if (remaining == 0) {
 		gtk_tree_row_reference_free (bud->ref_parent);
 		g_object_unref (bud->totem_grilo);
@@ -518,11 +497,16 @@ browse (TotemGriloPlugin *self,
 	if (source != NULL) {
 		BrowseUserData *bud;
 		GrlOperationOptions *default_options;
+		GrlCaps *caps;
+
+		caps = grl_source_get_caps (source, GRL_OP_BROWSE);
 
 		default_options = grl_operation_options_new (NULL);
 		grl_operation_options_set_flags (default_options, BROWSE_FLAGS);
 		grl_operation_options_set_skip (default_options, (page - 1) * PAGE_SIZE);
 		grl_operation_options_set_count (default_options, PAGE_SIZE);
+		if (grl_caps_get_type_filter (caps) & GRL_TYPE_FILTER_VIDEO)
+			grl_operation_options_set_type_filter (default_options, GRL_TYPE_FILTER_VIDEO);
 
 		bud = g_slice_new (BrowseUserData);
 		bud->totem_grilo = g_object_ref (self);
@@ -608,8 +592,6 @@ search_cb (GrlSource *source,
            gpointer user_data,
            const GError *error)
 {
-	gchar *description;
-	GtkTreeIter iter;
 	GdkPixbuf *thumbnail;
 	GtkWindow *window;
 	TotemGriloPlugin *self;
@@ -625,31 +607,36 @@ search_cb (GrlSource *source,
 	}
 
 	if (media != NULL) {
+		char *secondary;
+
 		self->priv->search_remaining--;
 		/* Filter images */
-		if (GRL_IS_MEDIA_IMAGE (media) == FALSE) {
-			thumbnail = get_icon (self, media, THUMB_SEARCH_SIZE);
-			description = get_description (media);
-
-			gtk_list_store_append (GTK_LIST_STORE (self->priv->search_results_model), &iter);
-			gtk_list_store_set (GTK_LIST_STORE (self->priv->search_results_model),
-			                    &iter,
-			                    MODEL_RESULTS_SOURCE, source,
-			                    MODEL_RESULTS_CONTENT, media,
-			                    MODEL_RESULTS_THUMBNAIL, thumbnail,
-			                    MODEL_RESULTS_IS_PRETHUMBNAIL, TRUE,
-			                    MODEL_RESULTS_DESCRIPTION, description,
-			                    -1);
-
-			if (thumbnail != NULL) {
-				g_object_unref (thumbnail);
-			}
-			g_free (description);
+		if (GRL_IS_MEDIA_IMAGE (media) ||
+		    GRL_IS_MEDIA_AUDIO (media)) {
+			g_object_unref (media);
+			goto out;
 		}
 
+		thumbnail = get_icon (self, media, THUMB_SEARCH_SIZE);
+		secondary = get_secondary_text (media);
+
+		gtk_list_store_insert_with_values (GTK_LIST_STORE (self->priv->search_results_model),
+						   NULL, -1,
+						   MODEL_RESULTS_SOURCE, source,
+						   MODEL_RESULTS_CONTENT, media,
+						   GD_MAIN_COLUMN_ICON, thumbnail,
+						   MODEL_RESULTS_IS_PRETHUMBNAIL, TRUE,
+						   GD_MAIN_COLUMN_PRIMARY_TEXT, grl_media_get_title (media),
+						   GD_MAIN_COLUMN_SECONDARY_TEXT, secondary,
+						   -1);
+
+		if (thumbnail != NULL)
+			g_object_unref (thumbnail);
+		g_free (secondary);
 		g_object_unref (media);
 	}
 
+out:
 	if (remaining == 0) {
 		self->priv->search_id = 0;
 		gtk_widget_set_sensitive (self->priv->search_entry, TRUE);
@@ -708,9 +695,8 @@ search_more (TotemGriloPlugin *self)
 	}
 	g_object_unref (search_options);
 
-	if (self->priv->search_id == 0) {
+	if (self->priv->search_id == 0)
 		search_cb (self->priv->search_source, 0, NULL, 0, self, NULL);
-	}
 }
 
 static void
@@ -792,13 +778,9 @@ browser_activated_cb (GtkTreeView *tree_view,
 		browse (self, path, source, content, page);
 	}
 
- free_data:
-	if (source != NULL) {
-		g_object_unref (source);
-	}
-	if (content != NULL) {
-		g_object_unref (content);
-	}
+free_data:
+	g_clear_object (&source);
+	g_clear_object (&content);
 }
 
 static void
@@ -833,13 +815,8 @@ search_activated_cb (GtkIconView *icon_view,
 
 	play (TOTEM_GRILO_PLUGIN (user_data), source, content, TRUE);
 
-	if (source != NULL) {
-		g_object_unref (source);
-	}
-
-	if (content != NULL) {
-		g_object_unref (content);
-	}
+	g_clear_object (&source);
+	g_clear_object (&content);
 }
 
 static gboolean
@@ -849,9 +826,8 @@ source_is_blacklisted (GrlSource *source)
 	const gchar **s = BLACKLIST_SOURCES;
 
 	while (*s) {
-		if (g_strcmp0 (*s, id) == 0) {
+		if (g_strcmp0 (*s, id) == 0)
 			return TRUE;
-		}
 		s++;
 	}
 
@@ -864,10 +840,7 @@ source_added_cb (GrlRegistry *registry,
                  gpointer user_data)
 {
 	const gchar *name;
-	gchar *description;
-	GdkPixbuf *icon;
 	TotemGriloPlugin *self;
-	GtkTreeIter iter;
 	GrlSupportedOps ops;
 
 	if (source_is_blacklisted (source)) {
@@ -878,34 +851,32 @@ source_added_cb (GrlRegistry *registry,
 	}
 
 	self = TOTEM_GRILO_PLUGIN (user_data);
-	icon = load_icon (self, ICON_BOX, THUMB_BROWSE_SIZE);
 	name = grl_source_get_name (source);
 	ops = grl_source_supported_operations (source);
 	if (ops & GRL_OP_BROWSE) {
-		description = g_markup_printf_escaped ("<b>%s</b>", name);
-		gtk_tree_store_append (GTK_TREE_STORE (self->priv->browser_model), &iter, NULL);
-		gtk_tree_store_set (GTK_TREE_STORE (self->priv->browser_model),
-		                    &iter,
-		                    MODEL_RESULTS_SOURCE, source,
-		                    MODEL_RESULTS_CONTENT, NULL,
-		                    MODEL_RESULTS_DESCRIPTION, description,
-		                    MODEL_RESULTS_THUMBNAIL, icon,
-		                    MODEL_RESULTS_IS_PRETHUMBNAIL, TRUE,
-		                    -1);
-		g_free (description);
+		GdkPixbuf *icon;
+
+		icon = load_icon (self, ICON_BOX, THUMB_BROWSE_SIZE);
+
+		gtk_tree_store_insert_with_values (GTK_TREE_STORE (self->priv->browser_model),
+						   NULL, NULL, -1,
+						   MODEL_RESULTS_SOURCE, source,
+						   MODEL_RESULTS_CONTENT, NULL,
+						   GD_MAIN_COLUMN_PRIMARY_TEXT, name,
+						   GD_MAIN_COLUMN_ICON, icon,
+						   MODEL_RESULTS_IS_PRETHUMBNAIL, TRUE,
+						   -1);
+
+		g_clear_object (&icon);
 	}
 	if (ops & GRL_OP_SEARCH) {
 		/* FIXME:
 		 * Handle tracker/filesystem specifically, so that we have a "local" entry here */
 		totem_search_entry_add_source (TOTEM_SEARCH_ENTRY (self->priv->search_entry),
 					       grl_source_get_id (source),
-					       grl_source_get_name (source),
+					       name,
 					       0); /* FIXME: Use correct priority */
 	}
-
-	if (icon != NULL) {
-		g_object_unref (icon);
-	}
 }
 
 static gboolean
@@ -924,9 +895,8 @@ remove_browse_result (GtkTreeModel *model,
 
 	same_source = (model_source == removed_source);
 
-	if (same_source) {
+	if (same_source)
 		gtk_tree_store_remove (GTK_TREE_STORE (model), iter);
-	}
 
 	g_object_unref (model_source);
 
@@ -1002,9 +972,8 @@ show_popup_menu (TotemGriloPlugin *self, GtkWidget *view, GdkEventButton *event)
 		/* Selection happened in browser view */
 		sel_tree = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
 
-		if (gtk_tree_selection_get_selected (sel_tree, &model, &iter) == FALSE) {
+		if (gtk_tree_selection_get_selected (sel_tree, &model, &iter) == FALSE)
 			return FALSE;
-		}
 	} else {
 		/* Selection happened in search view */
 		sel_list = gtk_icon_view_get_selected_items (GTK_ICON_VIEW (view));
@@ -1023,9 +992,8 @@ show_popup_menu (TotemGriloPlugin *self, GtkWidget *view, GdkEventButton *event)
 	}
 
 	/* Get rid of previously selected media */
-	if (self->priv->selected_media != NULL) {
+	if (self->priv->selected_media != NULL)
 		g_object_unref (self->priv->selected_media);
-	}
 
 	gtk_tree_model_get (model, &iter,
 	                    MODEL_RESULTS_SOURCE, &source,
@@ -1039,9 +1007,8 @@ show_popup_menu (TotemGriloPlugin *self, GtkWidget *view, GdkEventButton *event)
 		_time = gtk_get_current_event_time ();
 	}
 
-	if (self->priv->selected_media != NULL) {
+	if (self->priv->selected_media != NULL)
 		url = grl_media_get_url (self->priv->selected_media);
-	}
 
 	action = gtk_action_group_get_action (self->priv->action_group, "add-to-playlist");
 	gtk_action_set_sensitive (action, url != NULL);
@@ -1053,9 +1020,7 @@ show_popup_menu (TotemGriloPlugin *self, GtkWidget *view, GdkEventButton *event)
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
 	                button, _time);
 
-	if (source != NULL) {
-		g_object_unref (source);
-	}
+	g_clear_object (&source);
 
 	return TRUE;
 }
@@ -1095,18 +1060,15 @@ adjustment_value_changed_cb (GtkAdjustment *adjustment,
 	update_search_thumbnails (self);
 
 	/* Do not get more results if search is in progress */
-	if (self->priv->search_id != 0) {
+	if (self->priv->search_id != 0)
 		return;
-	}
 
 	/* Do not get more results if there are no more results to get :) */
-	if (self->priv->search_remaining > 0) {
+	if (self->priv->search_remaining > 0)
 		return;
-	}
 
-	if (adjustment_over_limit (adjustment)) {
+	if (adjustment_over_limit (adjustment))
 		search_more (self);
-	}
 }
 
 static void
@@ -1130,9 +1092,8 @@ get_more_browse_results_cb (GtkAdjustment *adjustment,
 	gint remaining;
 	gboolean stop_processing = FALSE;
 
-	if (adjustment_over_limit (adjustment) == FALSE) {
+	if (adjustment_over_limit (adjustment) == FALSE)
 		return;
-	}
 
 	if (gtk_tree_view_get_visible_range (GTK_TREE_VIEW (self->priv->browser),
 	                                     &start_path, &end_path) == FALSE) {
@@ -1179,15 +1140,9 @@ get_more_browse_results_cb (GtkAdjustment *adjustment,
 		stop_processing = TRUE;
 
 	free_elements:
-		if (source != NULL) {
-			g_object_unref (source);
-		}
-		if (container != NULL) {
-			g_object_unref (container);
-		}
-		if (parent_path) {
-			gtk_tree_path_free (parent_path);
-		}
+		g_clear_object (&source);
+		g_clear_object (&container);
+		g_clear_pointer (&parent_path, gtk_tree_path_free);
 
 	continue_next:
 		stop_processing = stop_processing || (gtk_tree_path_prev (end_path) == FALSE);
@@ -1335,9 +1290,8 @@ setup_config (TotemGriloPlugin *self)
 	/* Setup system-wide plugins configuration */
 	config_file = totem_plugin_find_file ("grilo", TOTEM_GRILO_CONFIG_FILE);
 
-	if (g_file_test (config_file, G_FILE_TEST_EXISTS)) {
+	if (g_file_test (config_file, G_FILE_TEST_EXISTS))
 		grl_registry_add_config_from_file (registry, config_file, NULL);
-	}
 	g_free (config_file);
 
 	/* Setup user-defined plugins configuration */
@@ -1347,9 +1301,8 @@ setup_config (TotemGriloPlugin *self)
 	                            TOTEM_GRILO_CONFIG_FILE,
 	                            NULL);
 
-	if (g_file_test (config_file, G_FILE_TEST_EXISTS)) {
+	if (g_file_test (config_file, G_FILE_TEST_EXISTS))
 		grl_registry_add_config_from_file (registry, config_file, NULL);
-	}
 	g_free (config_file);
 }
 
