@@ -87,33 +87,6 @@ error_handler (GstBus *bus,
 		exit (1);
 	case GST_MESSAGE_EOS:
 		exit (0);
-
-	case GST_MESSAGE_UNKNOWN:
-	case GST_MESSAGE_WARNING:
-	case GST_MESSAGE_INFO:
-	case GST_MESSAGE_TAG:
-	case GST_MESSAGE_BUFFERING:
-	case GST_MESSAGE_STATE_CHANGED:
-	case GST_MESSAGE_STATE_DIRTY:
-	case GST_MESSAGE_STEP_DONE:
-	case GST_MESSAGE_CLOCK_PROVIDE:
-	case GST_MESSAGE_CLOCK_LOST:
-	case GST_MESSAGE_NEW_CLOCK:
-	case GST_MESSAGE_STRUCTURE_CHANGE:
-	case GST_MESSAGE_STREAM_STATUS:
-	case GST_MESSAGE_APPLICATION:
-	case GST_MESSAGE_ELEMENT:
-	case GST_MESSAGE_SEGMENT_START:
-	case GST_MESSAGE_SEGMENT_DONE:
-	case GST_MESSAGE_DURATION:
-	case GST_MESSAGE_LATENCY:
-	case GST_MESSAGE_ASYNC_START:
-	case GST_MESSAGE_ASYNC_DONE:
-	case GST_MESSAGE_REQUEST_STATE:
-	case GST_MESSAGE_STEP_START:
-	case GST_MESSAGE_QOS:
-	case GST_MESSAGE_PROGRESS:
-	case GST_MESSAGE_ANY:
 	default:
 		/* Ignored */
 		;;
@@ -128,7 +101,7 @@ setup_errors (GstElement *play)
 	GstBus *bus;
 
 	bus = gst_element_get_bus (play);
-	gst_bus_set_sync_handler (bus, (GstBusSyncHandler) error_handler, play);
+	gst_bus_set_sync_handler (bus, (GstBusSyncHandler) error_handler, play, NULL);
 }
 
 static void
@@ -161,10 +134,6 @@ int main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-#if !GLIB_CHECK_VERSION (2, 31, 0)
-	g_thread_init (NULL);
-#endif
-
 	g_set_application_name (_("Audio Preview"));
 	g_setenv("PULSE_PROP_application.icon_name", "totem", TRUE);
 	g_setenv("PULSE_PROP_media.role", "music", TRUE);
@@ -202,7 +171,7 @@ int main (int argc, char **argv)
 		return 1;
 	}
 
-	play = gst_element_factory_make ("playbin2", "play");
+	play = gst_element_factory_make ("playbin", "play");
 	setup_play (play);
 	setup_filename (play);
 	setup_errors (play);
