@@ -69,13 +69,14 @@ typedef enum {
 } TotemStates;
 
 struct _TotemObject {
-	GObject parent;
+	GtkApplication parent;
 
 	/* Control window */
 	GtkBuilder *xml;
 	GtkWidget *win;
 	BaconVideoWidget *bvw;
 	GtkWidget *prefs;
+	GtkBuilder *prefs_xml;
 	GtkWidget *statusbar;
 
 	/* UI manager */
@@ -117,7 +118,6 @@ struct _TotemObject {
 	GtkWidget *languages;
 	GList *subtitles_list;
 	GList *language_list;
-	gboolean autoload_subs;
 
 	/* Fullscreen */
 	TotemFullscreen *fs;
@@ -152,11 +152,11 @@ struct _TotemObject {
 	gint64 seek_to;
 	TotemPlaylist *playlist;
 	GSettings *settings;
-	GtkApplication *app;
 	TotemStates state;
 	TotemOpenLocation *open_location;
 	gboolean remember_position;
 	gboolean disable_kbd_shortcuts;
+	gboolean has_played_emitted;
 };
 
 GtkWidget *totem_volume_create (void);
